@@ -16,7 +16,7 @@ require Exporter;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-11-15'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.342'; # VERSION
+our $VERSION = '0.343'; # VERSION
 
 our @ISA = qw(Exporter);
 our @EXPORT_OK = (
@@ -1604,7 +1604,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.342 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-11-15.
+This document describes version 0.343 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-11-15.
 
 =head1 SYNOPSIS
 
@@ -1693,7 +1693,15 @@ There is a command-line script interface for this module: L<list-id-holidays>.
 =head1 DEVELOPER NOTES
 
 To mark that a holiday has been moved from its original date, use the
-C<original_date> option.
+C<original_date> option. For example, Mawlid in 2021 has been moved from its
+original date 2021-11-19 (this is the day it is actually observed/commemorated)
+to 2021-11-20 (this is the day the holiday is in effect where offices and public
+places are closed). By adding this option, the summary will reflect this
+information:
+
+ date: 2021-12-20
+ eng_name: Mawlid (commemorated on 2021-12-19)
+ ind_name: Maulid Nabi Muhammad (diperingati 2021-12-19)
 
 =head1 FUNCTIONS
 
